@@ -76,7 +76,7 @@ static size_t strlcpy(char *dst, const char * const src, const size_t siz)
     char *d = dst;
     const char *s = src;
     size_t n = siz;
-    
+
     /* Copy as many bytes as will fit */
     if (n != 0 && --n != 0) {
         do {
@@ -85,7 +85,7 @@ static size_t strlcpy(char *dst, const char * const src, const size_t siz)
             }
         } while (--n != 0);
     }
-    
+
     /* Not enough room in dst, add NUL and traverse rest of src */
     if (n == 0) {
         if (siz != 0) {
@@ -93,7 +93,7 @@ static size_t strlcpy(char *dst, const char * const src, const size_t siz)
         }
         while (*s++) {
         }
-    }    
+    }
     return s - src - 1; /* count does not include NUL */
 }
 #endif
@@ -112,13 +112,13 @@ static size_t strlcat(char *dst, const char * const src, const size_t siz)
     const char *s = src;
     size_t n = siz;
     size_t dlen;
-    
+
     /* Find the end of dst and adjust bytes left but don't go past end */
     while (n-- != 0 && *d != '\0') {
         d++;
     }
     dlen = d - dst;
-    n = siz - dlen;    
+    n = siz - dlen;
     if (n == 0) {
         return dlen + strlen(s);
     }
@@ -130,7 +130,7 @@ static size_t strlcat(char *dst, const char * const src, const size_t siz)
         s++;
     }
     *d = '\0';
-    
+
     return dlen + (s - src);    /* count does not include NUL */
 }
 #endif
@@ -140,14 +140,14 @@ static size_t strlcat(char *dst, const char * const src, const size_t siz)
  * components.  Returns resolved on success, or NULL on failure,
  * in which case the path which caused trouble is left in (resolved).
  */
-char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
+char *bsd_realpath(const char *path, char resolved[PATH_MAX])
 {
     struct stat sb;
     char *p, *q, *s;
     size_t left_len, resolved_len;
     unsigned symlinks;
     int serrno, slen;
-    char left[MAXPATHLEN], next_token[MAXPATHLEN], symlink[MAXPATHLEN];
+    char left[PATH_MAX], next_token[PATH_MAX], symlink[PATH_MAX];
 
     serrno = errno;
     symlinks = 0;
@@ -160,18 +160,18 @@ char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
         resolved_len = 1;
         left_len = strlcpy(left, path + 1, sizeof left);
     } else {
-        if (getcwd(resolved, MAXPATHLEN) == NULL) {
-            strlcpy(resolved, ".", MAXPATHLEN);
+        if (getcwd(resolved, PATH_MAX) == NULL) {
+            strlcpy(resolved, ".", PATH_MAX);
             return NULL;
         }
         resolved_len = strlen(resolved);
         left_len = strlcpy(left, path, sizeof left);
     }
-    if (left_len >= sizeof left || resolved_len >= MAXPATHLEN) {
+    if (left_len >= sizeof left || resolved_len >= PATH_MAX) {
         errno = ENAMETOOLONG;
         return NULL;
     }
-    
+
     /*
      * Iterate over path components in `left'.
      */
@@ -193,7 +193,7 @@ char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
             memmove(left, s + 1, left_len + 1);
         }
         if (resolved[resolved_len - 1] != '/') {
-            if (resolved_len + 1 >= MAXPATHLEN) {
+            if (resolved_len + 1 >= PATH_MAX) {
                 errno = ENAMETOOLONG;
                 return NULL;
             }
@@ -215,22 +215,16 @@ char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
             }
             continue;
         }
-        
+
         /*
-         * Append the next path component and lstat() it. If
-         * lstat() fails we still can return successfully if
-         * there are no more path components left.
+         * Append the next path component and lstat() it.
          */
-        resolved_len = strlcat(resolved, next_token, MAXPATHLEN);
-        if (resolved_len >= MAXPATHLEN) {
+        resolved_len = strlcat(resolved, next_token, PATH_MAX);
+        if (resolved_len >= PATH_MAX) {
             errno = ENAMETOOLONG;
             return NULL;
         }
         if (lstat(resolved, &sb) != 0) {
-            if (errno == ENOENT && p == NULL) {
-                errno = serrno;
-                return resolved;
-            }
             return NULL;
         }
         if (S_ISLNK(sb.st_mode)) {
@@ -253,7 +247,7 @@ char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
                 *q = '\0';
                 resolved_len = q - resolved;
             }
-            
+
             /*
              * If there are any path components left, then
              * append them to symlink. The result is placed
@@ -268,16 +262,19 @@ char *bsd_realpath(const char *path, char resolved[MAXPATHLEN])
                     symlink[slen] = '/';
                     symlink[slen + 1] = 0;
                 }
-                left_len = strlcat(symlink, left, sizeof left);
+                left_len = strlcat(symlink, left, sizeof symlink);
                 if (left_len >= sizeof left) {
                     errno = ENAMETOOLONG;
                     return NULL;
                 }
             }
             left_len = strlcpy(left, symlink, sizeof left);
+        } else if (!S_ISDIR(sb.st_mode) && p != NULL) {
+            errno = ENOTDIR;
+            return NULL;
         }
     }
-    
+
     /*
      * Remove trailing slash except when the resolved pathname
      * is a single "/".
