@@ -104,7 +104,7 @@ static const char *GETOPT_OPTIONS =
     "y:"
 #endif
 #ifdef WITH_TLS
-    "Y:J:"
+    "2:Y:J:"
 #endif
     "zZ";
 
@@ -112,12 +112,15 @@ static const char *GETOPT_OPTIONS =
 static struct option long_options[] = {
     { "notruncate", 0, NULL, '0' },
     { "logpid", 0, NULL, '1' },
+# ifdef WITH_TLS
+    { "certfile", 1, NULL, '2' },
+# endif
     { "ipv4only", 0, NULL, '4' },
     { "ipv6only", 0, NULL, '6' },
-#ifdef WITH_RFC2640
+# ifdef WITH_RFC2640
     { "fscharset", 1, NULL, '8' },
     { "clientcharset", 1, NULL, '9' },
-#endif
+# endif
     { "chrooteveryone", 0, NULL, 'A' },
     { "trustedgid", 1, NULL, 'a' },
     { "brokenclientscompatibility", 0, NULL, 'b' },
