@@ -1,10 +1,13 @@
 #ifndef __LOG_MYSQL_H__
 #define __LOG_MYSQL_H__ 1
 
+#define PASSWD_SQL_ARGON2I "argon2i"
+#define PASSWD_SQL_SCRYPT "scrypt"
 #define PASSWD_SQL_CRYPT "crypt"
 #define PASSWD_SQL_CLEARTEXT "cleartext"
 #define PASSWD_SQL_MYSQL "password"
 #define PASSWD_SQL_MD5 "md5"
+#define PASSWD_SQL_SHA1 "sha1"
 #define PASSWD_SQL_ANY "any"
 #define MYSQL_DEFAULT_SERVER "localhost"
 #define MYSQL_DEFAULT_PORT 3306
