@@ -4,17 +4,22 @@
 
 #ifdef WITH_PGSQL
 
-#include "ftpd.h"
-#include "parser.h"
-#include "log_pgsql_p.h"
-#include "log_pgsql.h"
-#include "messages.h"
-#include "crypto.h"
-#include "alt_arc4random.h"
+# include "ftpd.h"
+# include "parser.h"
+# include "log_pgsql_p.h"
+# include "log_pgsql.h"
+# include "messages.h"
+# include "crypto.h"
+# include "alt_arc4random.h"
+# include "utils.h"
 
-#ifdef WITH_DMALLOC
-# include <dmalloc.h>
-#endif
+# ifdef HAVE_LIBSODIUM
+#  include <sodium.h>
+# endif
+
+# ifdef WITH_DMALLOC
+#  include <dmalloc.h>
+# endif
 
 static int pw_pgsql_validate_name(const char *name)
 {
@@ -404,7 +409,8 @@ void pw_pgsql_check(AuthResult * const result,
     char *escaped_decimal_ip = NULL;
     char *scrambled_password = NULL;
     int committed = 1;
-    int crypto_crypt = 0, crypto_md5 = 0, crypto_sha1 = 0, crypto_plain = 0;
+    int crypto_argon2i = 0, crypto_scrypt = 0, crypto_crypt = 0, crypto_md5 = 0,
+        crypto_sha1 = 0, crypto_plain = 0;
     unsigned long decimal_ip_num = 0UL;
     char decimal_ip[42];
     char hbuf[NI_MAXHOST];
@@ -493,9 +499,15 @@ void pw_pgsql_check(AuthResult * const result,
     }
     result->auth_ok--;                  /* -1 */
     if (strcasecmp(crypto, PASSWD_SQL_ANY) == 0) {
+        crypto_argon2i++;
+        crypto_scrypt++;
         crypto_crypt++;
         crypto_md5++;
         crypto_sha1++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_ARGON2I) == 0) {
+        crypto_argon2i++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_SCRYPT) == 0) {
+        crypto_scrypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_CRYPT) == 0) {
         crypto_crypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MD5) == 0) {
@@ -505,11 +517,26 @@ void pw_pgsql_check(AuthResult * const result,
     } else {                           /* default to plaintext */
         crypto_plain++;
     }
+#ifdef HAVE_LIBSODIUM
+# ifdef crypto_pwhash_STRPREFIX
+    if (crypto_argon2i != 0) {
+        if (crypto_pwhash_str_verify(spwd, password, strlen(password)) == 0) {
+            goto auth_ok;
+        }
+    }
+# endif
+    if (crypto_scrypt != 0) {
+        if (crypto_pwhash_scryptsalsa208sha256_str_verify
+            (spwd, password, strlen(password)) == 0) {
+            goto auth_ok;
+        }
+    }
+#endif
     if (crypto_crypt != 0) {
         const char *crypted;
 
         if ((crypted = (const char *) crypt(password, spwd)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
@@ -517,7 +544,7 @@ void pw_pgsql_check(AuthResult * const result,
         const char *crypted;
 
         if ((crypted = (const char *) crypto_hash_md5(password, 1)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
@@ -525,13 +552,13 @@ void pw_pgsql_check(AuthResult * const result,
         const char *crypted;
 
         if ((crypted = (const char *) crypto_hash_sha1(password, 1)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
     if (crypto_plain != 0) {
         if (*password != 0 &&    /* refuse null cleartext passwords */
-            strcmp(password, spwd) == 0) {
+            pure_strcmp(password, spwd) == 0) {
             goto auth_ok;
         }
     }
