@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: TLSCipherSuite invalide '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: TLSCipherSuite invalide '%s'"
 #define MSG_TIMEOUT "Temps de reponse depasse"
 #define MSG_CAPABILITIES "Impossible d'acceder a cette fonctionnalite"
 #define MSG_CLIENT_CLOSED_CNX "Le client a ferme la connexion"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Les raccourcis suivants sont utilisables :"
 #define MSG_PERUSER_MAX "Je ne peux pas accepter plus de %lu connexions du meme utilisateur"
 #define MSG_IPV6_OK "Les connections en IPv6 sont les bienvenues sur ce serveur."
-#define MSG_TLS_INFO "SSL/TLS: Protocole %s activ (%s), chiffrage en %d bits secrets"
-#define MSG_TLS_WEAK "SSL/TLS: Chiffrement trop faible"
+#define MSG_TLS_INFO "TLS: Protocole %s activ (%s), chiffrage en %d bits secrets"
+#define MSG_TLS_WEAK "TLS: Chiffrement trop faible"
 #define MSG_TLS_NEEDED "Desole, les sessions en clair ne sont pas acceptees sur ce serveur.\n" \
-    "Veuillez vous reconnecter en utilisant les mechanismes de securite SSL/TLS."
+    "Veuillez vous reconnecter en utilisant les mechanismes de securite TLS."
 #define MSG_ILLEGAL_CHARSET "Jeu de caracteres illegal"
-#define MSG_TLS_NO_CTX "SSL/TLS: context non trouve. Deconnexion."
+#define MSG_TLS_NO_CTX "TLS: context non trouve. Deconnexion."
 #define MSG_PROT_OK "Niveau de protection regle a \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "La connexion pour les donnees ne peut etre cree avec ce niveau de protection (PROT)."
 #define MSG_PROT_UNKNOWN_LEVEL "Niveau de protection %s non pris en charge. Utilisation de \"%s\""
