@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Id?tllps"
 #define MSG_CAPABILITIES "Kpessg vlts sikertelen"
 #define MSG_CLIENT_CLOSED_CNX "A Kliens bontotta a kapcsolatot"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "A kvetkezo aliasok elrhetoek :"
 #define MSG_PERUSER_MAX "Nem fogadhatok el tbb kapcsolatot, mint %lu ugyanattl a felhasznltl"
 #define MSG_IPV6_OK "IPv6 kapcsolatok szintn hasznlhatak a szerveren."
-#define MSG_TLS_INFO "SSL/TLS: Engedlyezve %s, %s, %d titkos bittel titkostva"
-#define MSG_TLS_WEAK "SSL/TLS: Titkosts tl gyenge"
+#define MSG_TLS_INFO "TLS: Engedlyezve %s, %s, %d titkos bittel titkostva"
+#define MSG_TLS_WEAK "TLS: Titkosts tl gyenge"
 #define MSG_TLS_NEEDED "Hiba, cleartext belpsi forma nem engedlyezett.\n" \
-    "Krem kapcsoldjon jra SSL/TLS biztonsgi mdot hasznlva."
+    "Krem kapcsoldjon jra TLS biztonsgi mdot hasznlva."
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
