@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Kan ikke endre egenskaper"
 #define MSG_CLIENT_CLOSED_CNX "Klienten lukket tilkoblingen"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Flgende alias er tilgjengelige:"
 #define MSG_PERUSER_MAX "Kan ikke akseptere mer enn %lu tilkoblinger fra samme bruker"
 #define MSG_IPV6_OK "IPv6-forbindelser er ogs velkomne p denne serveren"
-#define MSG_TLS_INFO "SSL/TLS: Aktivert %s med %s, %d bits kryperingsnkkel"
-#define MSG_TLS_WEAK "SSL/TLS: Krypteringsnkkelen er for svak"
+#define MSG_TLS_INFO "TLS: Aktivert %s med %s, %d bits kryperingsnkkel"
+#define MSG_TLS_WEAK "TLS: Krypteringsnkkelen er for svak"
 #define MSG_TLS_NEEDED "Beklager, klartekst-forbindelser er ikke tillatt p denne serveren.\n" \
-    "Vr vennlig  koble til p nytt ved bruk av SSL/TLS-sikkerhetsmekanismer."
+    "Vr vennlig  koble til p nytt ved bruk av TLS-sikkerhetsmekanismer."
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
