@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Przekroczony czas oczekiwania"
 #define MSG_CAPABILITIES "Nie mona przecza capabilities"
 #define MSG_CLIENT_CLOSED_CNX "Klient zamkn poczenie"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "The following aliases are available :"
 #define MSG_PERUSER_MAX "I can't accept more than %lu connections from the same user"
 #define MSG_IPV6_OK "IPv6 connections are also welcome on this server"
-#define MSG_TLS_INFO "SSL/TLS: Enabled %s with %s, %d secret bits cipher"
-#define MSG_TLS_WEAK "SSL/TLS: Cipher too weak"
+#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
+#define MSG_TLS_WEAK "TLS: Cipher too weak"
 #define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
-    "Please reconnect using SSL/TLS security mechanisms."
+    "Please reconnect using TLS security mechanisms."
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
