@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Tempo expirado"
 #define MSG_CAPABILITIES "No foi possvel trocar capacidades"
 #define MSG_CLIENT_CLOSED_CNX "Cliente encerrou a conexo"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Os seguintes apelidos esto disponveis :"
 #define MSG_PERUSER_MAX "No posso aceitar mais do que %lu conexes do mesmo usurio"
 #define MSG_IPV6_OK "Conexes IPv6 tambm so bem-vindas neste servidor"
-#define MSG_TLS_INFO "SSL/TLS: Habilitado %s com %s, criptografia de %d bits"
-#define MSG_TLS_WEAK "SSL/TLS: Criptografia muito fraca"
+#define MSG_TLS_INFO "TLS: Habilitado %s com %s, criptografia de %d bits"
+#define MSG_TLS_WEAK "TLS: Criptografia muito fraca"
 #define MSG_TLS_NEEDED "Desculpe, sesses sem criptografia no so aceitas neste servidor.\n" \
-    "Por favor reconecte-se usando mecanismos de segurana SSL/TLS."
+    "Por favor reconecte-se usando mecanismos de segurana TLS."
 #define MSG_ILLEGAL_CHARSET "Conjunto de caracteres ilegal"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
