@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Temporizare expirata"
 #define MSG_CAPABILITIES "Nu pot comuta capabilitatile"
 #define MSG_CLIENT_CLOSED_CNX "Clientul a inchis conexiunea"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Sint disponibile urmatoarele aliasuri: "
 #define MSG_PERUSER_MAX "Nu pot accepta mai mult de %lu conexiuni de la acelasi utilizator"
 #define MSG_IPV6_OK "Conexiunile IPv6 sint acceptate de catre acest server"
-#define MSG_TLS_INFO "SSL/TLS: Am activat %s cu %s, criptare cu %d biti"
-#define MSG_TLS_WEAK "SSL/TLS: Sistem de criptare prea slab"
+#define MSG_TLS_INFO "TLS: Am activat %s cu %s, criptare cu %d biti"
+#define MSG_TLS_WEAK "TLS: Sistem de criptare prea slab"
 #define MSG_TLS_NEEDED "Sesiunile in text clar nu sint acceptate pe acest server.\n" \
-    "Reconectati-va utilizind mecanismele de securitate SSL/TLS."
+    "Reconectati-va utilizind mecanismele de securitate TLS."
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
