@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "ʱ"
 #define MSG_CAPABILITIES "޷л"
 #define MSG_CLIENT_CLOSED_CNX "û˹ر"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "µıã"
 #define MSG_PERUSER_MAX "޷ͬһʹ߳ %lu "
 #define MSG_IPV6_OK "ⲿҲӭIPv6"
-#define MSG_TLS_INFO "SSL/TLS:  %s with %s, %d λԪ"
-#define MSG_TLS_WEAK "SSL/TLS: 벻"
+#define MSG_TLS_INFO "TLS:  %s with %s, %d λԪ"
+#define MSG_TLS_WEAK "TLS: 벻"
 #define MSG_TLS_NEEDED "Ǹ˷ʽӡ\n" \
-    "ʹSSL/TLSİȫӡ"
+    "ʹTLSİȫӡ"
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
