@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "O"
 #define MSG_CAPABILITIES "Lkʯ"
 #define MSG_CLIENT_CLOSED_CNX "Τsu"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "HUOWiΡG"
 #define MSG_PERUSER_MAX "LkӦۦP@ϥΪ̶WL %lu su"
 #define MSG_IPV6_OK "oD]wIPv6su"
-#define MSG_TLS_INFO "SSL/TLS: ҥ %s with %s, %d 줸[K"
-#define MSG_TLS_WEAK "SSL/TLS: KX"
+#define MSG_TLS_INFO "TLS: ҥ %s with %s, %d 줸[K"
+#define MSG_TLS_WEAK "TLS: KX"
 #define MSG_TLS_NEEDED "pAA妡suC\n" \
-    "ШϥSSL/TLSwssuC"
+    "ШϥTLSwssuC"
 #define MSG_ILLEGAL_CHARSET "Illegal charset"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
 #define MSG_PROT_OK "Data protection level set to \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
