@@ -4,9 +4,13 @@
 #ifdef WITH_TLS
 
 # include <openssl/ssl.h>
+# include <openssl/dh.h>
+# include <openssl/bn.h>
 # include <openssl/err.h>
 # include <openssl/rand.h>
-# include <openssl/ec.h>
+# ifdef HAVE_OPENSSL_EC_H
+#  include <openssl/ec.h>
+# endif
 
 int tls_init_library(void);
 void tls_free_library(void);
